==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fLdc1.h <==
// class soot.coffi.Instruction_Ldc1

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class c79f5ba5a19d0bdd soot_coffi_Instruction__5fLdc1
// @dep_class 34236df30d2a0a89 soot_coffi_Instruction__5fbyteindex

// header file dependencies
// @dep_header soot_coffi_Instruction__5fbyteindex

#include "soot/coffi/Instruction__5fbyteindex.h"

#ifndef _JC_soot_coffi_Instruction__5fLdc1_H_
#define _JC_soot_coffi_Instruction__5fLdc1_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fLdc1$sub_refs	_jc_soot_coffi_Instruction__5fLdc1$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fLdc1$sub_nonrefs	_jc_soot_coffi_Instruction__5fLdc1$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLdc1$refs	_jc_soot_coffi_Instruction__5fLdc1$refs;
typedef struct _jc_soot_coffi_Instruction__5fLdc1$nonrefs	_jc_soot_coffi_Instruction__5fLdc1$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLdc1$object	_jc_soot_coffi_Instruction__5fLdc1$object;

typedef const struct _jc_soot_coffi_Instruction__5fLdc1$vmethods	_jc_soot_coffi_Instruction__5fLdc1$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fLdc1$vtable	_jc_soot_coffi_Instruction__5fLdc1$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fLdc1$vtype	_jc_soot_coffi_Instruction__5fLdc1$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fLdc1$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fLdc1$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fLdc1$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fLdc1$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbyteindex$vmethods	soot_coffi_Instruction__5fbyteindex;
	_jc_soot_coffi_Instruction__5fLdc1$vmethods	soot_coffi_Instruction__5fLdc1;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fLdc1$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fLdc1$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLdc1$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLdc1$refs {
    _jc_soot_coffi_Instruction__5fLdc1$sub_refs	soot_coffi_Instruction__5fLdc1;
    _jc_soot_coffi_Instruction__5fbyteindex$sub_refs	soot_coffi_Instruction__5fbyteindex;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLdc1$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLdc1$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbyteindex$sub_nonrefs	soot_coffi_Instruction__5fbyteindex;
    _jc_soot_coffi_Instruction__5fLdc1$sub_nonrefs	soot_coffi_Instruction__5fLdc1;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fLdc1$object {
	_jc_soot_coffi_Instruction__5fLdc1$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fLdc1$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fLdc1$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fLdc1$vtype _jc_soot_coffi_Instruction__5fLdc1$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fLdc1, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fLdc1$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fLdc1_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fLdc1.h <==
// class soot.coffi.Instruction_Ldc1

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class c79f5ba5a19d0bdd soot_coffi_Instruction__5fLdc1
// @dep_class 34236df30d2a0a89 soot_coffi_Instruction__5fbyteindex

// header file dependencies
// @dep_header soot_coffi_Instruction__5fbyteindex

#include "soot/coffi/Instruction__5fbyteindex.h"

#ifndef _JC_soot_coffi_Instruction__5fLdc1_H_
#define _JC_soot_coffi_Instruction__5fLdc1_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fLdc1$sub_refs	_jc_soot_coffi_Instruction__5fLdc1$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fLdc1$sub_nonrefs	_jc_soot_coffi_Instruction__5fLdc1$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLdc1$refs	_jc_soot_coffi_Instruction__5fLdc1$refs;
typedef struct _jc_soot_coffi_Instruction__5fLdc1$nonrefs	_jc_soot_coffi_Instruction__5fLdc1$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLdc1$object	_jc_soot_coffi_Instruction__5fLdc1$object;

typedef const struct _jc_soot_coffi_Instruction__5fLdc1$vmethods	_jc_soot_coffi_Instruction__5fLdc1$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fLdc1$vtable	_jc_soot_coffi_Instruction__5fLdc1$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fLdc1$vtype	_jc_soot_coffi_Instruction__5fLdc1$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fLdc1$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fLdc1$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fLdc1$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fLdc1$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbyteindex$vmethods	soot_coffi_Instruction__5fbyteindex;
	_jc_soot_coffi_Instruction__5fLdc1$vmethods	soot_coffi_Instruction__5fLdc1;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fLdc1$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fLdc1$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLdc1$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLdc1$refs {
    _jc_soot_coffi_Instruction__5fLdc1$sub_refs	soot_coffi_Instruction__5fLdc1;
    _jc_soot_coffi_Instruction__5fbyteindex$sub_refs	soot_coffi_Instruction__5fbyteindex;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLdc1$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLdc1$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbyteindex$sub_nonrefs	soot_coffi_Instruction__5fbyteindex;
    _jc_soot_coffi_Instruction__5fLdc1$sub_nonrefs	soot_coffi_Instruction__5fLdc1;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fLdc1$object {
	_jc_soot_coffi_Instruction__5fLdc1$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fLdc1$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fLdc1$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fLdc1$vtype _jc_soot_coffi_Instruction__5fLdc1$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fLdc1, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fLdc1$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fLdc1_H_ */
